@@ -72,6 +72,7 @@ extern int log_level;
 
 const HTTP_Servers default_server[]= {
 	{ "hotmail.com", "http://oe.hotmail.com/cgi-bin/hmdata" },
+	{ "hotmail.co.uk", "http://oe.hotmail.com/cgi-bin/hmdata" },
 	{ "msn.com", "http://oe.msn.msnmail.hotmail.com/cgi-bin/hmdata" },
 	{ "lycos.co.uk", "http://webdav.lycos.co.uk/httpmail.asp" },
 	{ "lycos.ch", "http://webdav.lycos.de/httpmail.asp" },
@@ -81,6 +82,7 @@ const HTTP_Servers default_server[]= {
 	{ "lycos.at", "http://webdav.lycos.at/httpmail.asp" },
 	{ "lycos.nl", "http://webdav.lycos.nl/httpmail.asp" },
 	{ "spray.se", "http://webdav.spray.se/httpmail.asp" },
+	{ "caramail.com", "http://webdav.caramail.lycos.fr/httpmail.asp" },
 };
 
 
@@ -165,8 +167,9 @@ static void save_cookies(ghttp_request *request)
 		if (value[0] == '\"') value++;
 
 		if (!strcmp(key, "domain")) { /* Read domain for this cookie */
-			cookiedomain = strdup(value);
-			if (j != -1) cookies[j]->domain = cookiedomain;
+		        cookiedomain = strdup(value); 
+			/* the next time causes problems with httpmail_destroy so removed */
+			/* if (j != -1) cookies[j]->domain = cookiedomain; */
 		}
 		else if (strcmp(key, "path")) { /* Read key/value for this cookie, ignoring path*/
 
@@ -754,6 +757,7 @@ void httpmail_destroy(void)
 	if (cookies)   free(cookies);
 	cookies= NULL;
 	if (request)   ghttp_request_destroy(request);
+	request = NULL;
 	if (trash && trash->href) {
 	  free(trash->href);
 	  trash->href=NULL;
