@@ -110,6 +110,12 @@ unsigned long body_len=compute_list_size(&HEADERS) + compute_list_size(&MAILDATA
   /* Do the work */
   httpmail_send(smtpurl->href, body, body_len);
 
+  /* clean up malloced data */
+  if (body != NULL) {
+      free(body);
+      body = NULL;
+  }
+
   /* reset to authenticated */
   *state = AUTHENTICATED;
 }
@@ -135,8 +141,9 @@ char *buffer;
 
   len=strlen(input);
   if(len > MAX_TEXT_LEN) {
-    PSOUT("501 DATA line too long");
+    PSOUT("500 DATA line too long");
     PCRLF;
+    return;    
   }
   if(*state == DATA)
   {
@@ -198,9 +205,5 @@ void httpmail_send(char *sendmsg_url, char *body, unsigned long body_len)
   PCRLF;
   }
 
-  /* Clean up after ourselves */
-  httpmail_destroy();
-  if (body)
-      free(body);
 }
 
